==> ein_drag-0.1.11.tgz: package/src/store/modules/drag.js <==
import { setState } from '@/utils'
import Vue from 'vue'
import dragApi from '@/api/drag'

const drag = {
  namespaced: true,
  state: {
    dragComponentsModule: null,
    pageData: {
      pageInfo: {},
      componentsList: []
    },
    // 这个值用来当v-for的key，不能重复，transition组件需要
    uniqueKey: 0,
    currentComponent: null
  },
  mutations: {
    setState,
    initPage(state, defaultPageData) {
      if (defaultPageData) {
        // let { pageData, componentsList } = defaultPageData
        state.pageData = defaultPageData
      } else {
        // 使用默认值
        let defaultPageData = {
          pageInfo: {
            title: '页面设置',
            component: 'page',
            pageName: '',
            description: ''
          },
          componentsList: []
        }
        state.pageData = defaultPageData
        state.uniqueKey = 0
      }
    },
    setComponents(state, { componentsList }) {
      state.pageData.componentsList = componentsList
    },
    setPageInfo(state, { pageInfo }) {
      state.pageData.pageInfo = pageInfo
    },
    setCurrentComponent(state, { currentComponent }) {
      if (currentComponent === 'page') {
        state.currentComponent = state.pageData.pageInfo
      } else {
        state.currentComponent = currentComponent
      }
    }
  },
  actions: {
    drawComponent({ commit, state }, { component }) {
      let newComponent = JSON.parse(JSON.stringify(component))
      newComponent.key = new Date().getTime() + '-' + (state.uniqueKey + 1)
      let componentsList = state.pageData.componentsList.concat(newComponent)
      commit('setComponents', { componentsList })
      commit('setCurrentComponent', { currentComponent: newComponent })
      commit('setState', { uniqueKey: state.uniqueKey + 1 })
    },
    savePage({ commit, state }) {
      return new Promise((resolve, reject) => {
        let data = {
          id: 195,
          title: state.pageData.pageInfo.title,
          description: state.pageData.pageInfo.description,
          content: JSON.stringify(state.pageData)
        }
        dragApi.updateDragPage(data).then((res) => {
          resolve()
        })
      })
    },
    getDragComponent({ commit, state }) {
      return new Promise((resolve, reject) => {
        if (state.dragComponents) {
          // 避免重复加载
          return resolve()
        }
        // import('@lib/ein_drag.umd.js').then((res) => {
        import('@packages/index.js').then((res) => {
          let einDrag = res.default
          console.log(einDrag)
          commit('setState', { dragComponentsModule: einDrag })
          Vue.use(einDrag)
          resolve()
        })
        // 通过script方式引入，后面其他引入该组件的项目，推荐将js组件放公用服务器，更新组件即可实现更新
        /* let sc = document.createElement('script')
        sc.src = 'https://cdn.jsdelivr.net/npm/ein_drag@0.1.1/lib/ein_drag.umd.js'
        sc.onload = () => {
          let einDrag = window.ein_drag.default
          console.log(window.ein_drag)
          console.log(einDrag, Object.keys(einDrag).length)
          commit('setState', { dragComponents: einDrag })
          Vue.use(einDrag)
          this.show = true
          resolve()
        }
        sc.onerror = (err) => {
          reject(err)
        }
        document.body.append(sc) */
      })
    }
  }
}

export default drag

==> ein_drag-0.1.18.tgz: package/src/store/modules/drag.js <==
import { setState } from '@/utils'
import Vue from 'vue'
import dragApi from '@/api/drag'

const drag = {
  namespaced: true,
  state: {
    dragComponentsModule: null,
    pageData: {
      pageInfo: {},
      componentsList: []
    },
    // 这个值用来当v-for的key，不能重复，transition组件需要
    uniqueKey: 0,
    currentComponent: null
  },
  mutations: {
    setState,
    initPage(state, defaultPageData) {
      if (defaultPageData) {
        // let { pageData, componentsList } = defaultPageData
        state.pageData = defaultPageData
      } else {
        // 使用默认值
        let defaultPageData = {
          pageInfo: {
            title: '页面设置',
            component: 'page',
            pageName: '',
            description: ''
          },
          componentsList: []
        }
        state.pageData = defaultPageData
        state.uniqueKey = 0
      }
    },
    setComponents(state, { componentsList }) {
      state.pageData.componentsList = componentsList
    },
    setPageInfo(state, { pageInfo }) {
      state.pageData.pageInfo = pageInfo
    },
    setCurrentComponent(state, { currentComponent }) {
      if (currentComponent === 'page') {
        state.currentComponent = state.pageData.pageInfo
      } else {
        state.currentComponent = currentComponent
      }
    }
  },
  actions: {
    drawComponent({ commit, state }, { component }) {
      let newComponent = JSON.parse(JSON.stringify(component))
      newComponent.key = new Date().getTime() + '-' + (state.uniqueKey + 1)
      let componentsList = state.pageData.componentsList.concat(newComponent)
      commit('setComponents', { componentsList })
      commit('setCurrentComponent', { currentComponent: newComponent })
      commit('setState', { uniqueKey: state.uniqueKey + 1 })
    },
    savePage({ commit, state }) {
      return new Promise((resolve, reject) => {
        let data = {
          id: 195,
          title: state.pageData.pageInfo.title,
          description: state.pageData.pageInfo.description,
          content: JSON.stringify(state.pageData)
        }
        dragApi.updateDragPage(data).then((res) => {
          resolve()
        })
      })
    },
    getDragComponent({ commit, state }) {
      return new Promise((resolve, reject) => {
        if (state.dragComponents) {
          // 避免重复加载
          return resolve()
        }
        // import('@lib/ein_drag.css').then((res) => {})
        import('@lib/ein_drag.umd.js').then((res) => {
          // import('@packages/index.js').then((res) => {
          let einDrag = res.default
          console.log(einDrag)
          commit('setState', { dragComponentsModule: einDrag })
          Vue.use(einDrag)
          resolve()
        })
        // 通过script方式引入，后面其他引入该组件的项目，推荐将js组件放公用服务器，更新组件即可实现更新
        /* let sc = document.createElement('script')
        sc.src = 'https://cdn.jsdelivr.net/npm/ein_drag@0.1.11/lib/ein_drag.umd.js'
        sc.onload = () => {
          let einDrag = window.ein_drag.default
          console.log(window.ein_drag)
          console.log(einDrag, Object.keys(einDrag).length)
          commit('setState', { dragComponents: einDrag })
          Vue.use(einDrag)
          this.show = true
          resolve()
        }
        sc.onerror = (err) => {
          reject(err)
        }
        document.body.append(sc) */
      })
    }
  }
}

export default drag
